#[repr(C)]pub struct NoCalcAngle {
unit: AngleUnit,
value: CSSFloat,
}Expand description
A non-calc <angle> value.
Fields
unit: AngleUnitvalue: CSSFloatImplementations
Sourceimpl NoCalcAngle
impl NoCalcAngle
Sourcepub fn new(unit: AngleUnit, value: CSSFloat) -> Self
pub fn new(unit: AngleUnit, value: CSSFloat) -> Self
Creates an angle with the given unit and value.
Sourcepub fn from_degrees(value: CSSFloat) -> Self
pub fn from_degrees(value: CSSFloat) -> Self
Creates an angle with the given value in degrees.
Sourcepub fn from_radians(value: CSSFloat) -> Self
pub fn from_radians(value: CSSFloat) -> Self
Creates an angle with the given value in radians.
Sourcepub fn angle_unit(&self) -> AngleUnit
pub fn angle_unit(&self) -> AngleUnit
Returns the unit of the angle.
Sourcepub fn unitless_value(&self) -> CSSFloat
pub fn unitless_value(&self) -> CSSFloat
Returns the unitless, raw value.
Sourcepub fn canonical_unit(&self) -> Option<&'static str>
pub fn canonical_unit(&self) -> Option<&'static str>
Return the canonical unit for this value.